@@ -9,7 +9,7 @@ autoreconf
   --with-libiconv-prefix=$PREFIX/iconv \
   --enable-static \
   PTW32_LIBS="-lpthread -lpcreposix -lpcre -lregex" \
-  FLTK_CONFIG=$PREFIX/bin/i686-w64-mingw32.static-fltk-config
+  FLTK_CONFIG=$PREFIX/i686-w64-mingw32.static/bin/fltk-config
 
 make
 $PREFIX/bin/i686-w64-mingw32.static-strip src/flrig.exe
