@@ -33,6 +33,7 @@
 #include "rigbase.h"
 #include "font_browser.h"
 #include "ui.h"
+#include "status.h"
 
 #include <string>
 
@@ -55,6 +56,8 @@ using namespace std;
 #include "rig.h"
 #include "socket_io.h"
 
+#include "rigpanel.h"
+
 Fl_Double_Window *dlgDisplayConfig = NULL;
 Fl_Double_Window *dlgXcvrConfig = NULL;
 Fl_Double_Window *dlgMemoryDialog = NULL;
@@ -85,6 +88,13 @@ void add_combos(char *port)
 	selectSepPTTPort->add(port);
 }
 
+void add_status_to_combos()
+{
+	selectCommPort->add(progStatus.xcvr_serial_port.c_str());
+	selectAuxPort->add(progStatus.aux_serial_port.c_str());
+	selectSepPTTPort->add(progStatus.sep_serial_port.c_str());
+}
+
 //======================================================================
 // WIN32 init_port_combos
 //======================================================================
@@ -117,6 +127,7 @@ void init_port_combos()
 		LOG_WARN("Found serial port %s", ttyname);
 		add_combos(ttyname);
 	}
+	add_status_to_combos();
 }
 #endif //__WIN32__
 
@@ -154,6 +165,18 @@ void init_port_combos()
 	}
 	globfree(&gbuf);
 
+	glob("/dev/tty*", 0, NULL, &gbuf);
+	for (size_t j = 0; j < gbuf.gl_pathc; j++) {
+		if ( !(stat(gbuf.gl_pathv[j], &st) == 0 && S_ISCHR(st.st_mode)) ||
+		     strstr(gbuf.gl_pathv[j], "modem") )
+			continue;
+std::cout << "Serial port: " << gbuf.gl_pathv[j] << std::endl;
+		LOG_QUIET("Found serial port %s", gbuf.gl_pathv[j]);
+			add_combos(gbuf.gl_pathv[j]);
+	}
+
+	globfree(&gbuf);
+
 	if (getcwd(cwd, sizeof(cwd)) == NULL) goto out;
 
 	if (chdir("/sys/class/tty") == -1) goto check_cuse;
@@ -234,8 +257,10 @@ out:
 
 	if (sys) closedir(sys);
 	if (chdir(cwd) == -1) return;
-	if (ret) // do we need to fall back to the probe code below?
+	if (ret) { // do we need to fall back to the probe code below?
+		add_status_to_combos();
 		return;
+	}
 
 	const char* tty_fmt[] = {
 		"/dev/ttyS%u",
@@ -253,7 +278,7 @@ out:
 			add_combos(ttyname);
 		}
 	}
-
+	add_status_to_combos();
 }
 #endif // __linux__
 
@@ -290,6 +315,7 @@ void init_port_combos()
 		}
 		globfree(&gbuf);
 	}
+	add_status_to_combos();
 }
 #endif //__APPLE__
 
@@ -543,6 +569,43 @@ void cb_change_hrd_button()
 	FreqDispB->set_hrd(progStatus.hrd_buttons);
 }
 
+void set_sliders_when()
+{
+	if (sldrSQUELCH)
+		sldrSQUELCH->when(progStatus.sliders_button);
+	if (sldrMICGAIN)
+		sldrMICGAIN->when(progStatus.sliders_button);
+	if (sldrIFSHIFT)
+		sldrIFSHIFT->when(progStatus.sliders_button);
+	if (sldrNR)
+		sldrNR->when(progStatus.sliders_button);
+	if (sldrNOTCH)
+		sldrNOTCH->when(progStatus.sliders_button);
+	if (sldrRFGAIN)
+		sldrRFGAIN->when(progStatus.sliders_button);
+	if (sldrINNER)
+		sldrINNER->when(progStatus.sliders_button);
+	if (sldrOUTER)
+		sldrOUTER->when(progStatus.sliders_button);
+	if (sldrPOWER)
+		sldrPOWER->when(progStatus.sliders_button);
+	if (sldrVOLUME)
+		sldrVOLUME->when(progStatus.sliders_button);
+	if (ic7610_digi_sel_val)
+		ic7610_digi_sel_val->when(progStatus.sliders_button);
+	if (sldr_nb_level)
+		sldr_nb_level->when(progStatus.sliders_button);
+}
+
+void cb_change_sliders_button()
+{
+	if (progStatus.sliders_button == FL_WHEN_CHANGED)
+		progStatus.sliders_button = FL_WHEN_RELEASE;
+	else
+		progStatus.sliders_button = FL_WHEN_CHANGED;
+	set_sliders_when();
+}
+
 void cb_slider_defaults()
 {
 	bg_slider_red = 232;
@@ -1051,8 +1114,6 @@ void openMemoryDialog()
 
 void show_controls()
 {
-	if (selrig->name_ == rig_TT550.name_)
-		return;
 	int wh = mainwindow->h();
 	int ww = mainwindow->w();
 	switch (progStatus.UIsize) {
